@@ -23,10 +23,8 @@
 #include <config.h>
 #include <string.h>
 #include <unistd.h>
-
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include "file-utils.h"
 #include "fr-stock.h"
 #include "fr-window.h"
@@ -66,10 +64,12 @@ file_sel_response_cb (GtkWidget      *widget,
 	current_folder = gtk_file_chooser_get_current_folder_uri (file_sel);
 	uri = gtk_file_chooser_get_uri (file_sel);
 	eel_gconf_set_string (PREF_ADD_CURRENT_FOLDER, current_folder);
-	eel_gconf_set_string (PREF_ADD_FILENAME, uri);
+	if (uri != NULL) {
+		eel_gconf_set_string (PREF_ADD_FILENAME, uri);
+	}
 	fr_window_set_add_default_dir (window, current_folder);
 	g_free (uri);
-	
+
 	if ((response == GTK_RESPONSE_CANCEL) || (response == GTK_RESPONSE_DELETE_EVENT)) {
 		gtk_widget_destroy (data->dialog);
 		g_free (current_folder);
@@ -84,8 +84,7 @@ file_sel_response_cb (GtkWidget      *widget,
 
 	/* check folder permissions. */
 
-	if (uri_is_dir (current_folder)
-	    && ! check_permissions (current_folder, R_OK | X_OK)) {
+	if (uri_is_dir (current_folder) && ! check_permissions (current_folder, R_OK)) {
 		GtkWidget *d;
 		char      *utf8_path;
 
@@ -95,7 +94,7 @@ file_sel_response_cb (GtkWidget      *widget,
 					   GTK_DIALOG_MODAL,
 					   NULL,
 					   _("Could not add the files to the archive"),
-					   _("You don't have the right permissions to read files from folder \"%s\""), 
+					   _("You don't have the right permissions to read files from folder \"%s\""),
 					   utf8_path);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
@@ -111,14 +110,14 @@ file_sel_response_cb (GtkWidget      *widget,
 
 	selections = gtk_file_chooser_get_uris (file_sel);
 	for (iter = selections; iter != NULL; iter = iter->next) {
-		char *path = iter->data;
-		item_list = g_list_prepend (item_list, path);
+		char *uri = iter->data;
+		item_list = g_list_prepend (item_list, g_file_new_for_uri (uri));
 	}
 
 	if (item_list != NULL)
 		fr_window_archive_add_files (window, item_list, update);
 
-	g_list_free (item_list);
+	gio_file_list_free (item_list);
 	g_slist_foreach (selections, (GFunc) g_free, NULL);
 	g_slist_free (selections);
 	g_free (current_folder);
@@ -138,7 +137,7 @@ add_files_cb (GtkWidget *widget,
 	DialogData *data;
 	GtkWidget  *main_box;
 	char       *folder;
-	
+
 	data = g_new0 (DialogData, 1);
 	data->window = callback_data;
 	data->dialog = file_sel =
@@ -156,6 +155,8 @@ add_files_cb (GtkWidget *widget,
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), FALSE);
 	gtk_dialog_set_default_response (GTK_DIALOG (file_sel), GTK_RESPONSE_OK);
 
+	/* Translators: add a file to the archive only if the disk version is
+	 * newer than the archive version. */
 	data->add_if_newer_checkbutton = gtk_check_button_new_with_mnemonic (_("Add only if _newer"));
 
 	main_box = gtk_hbox_new (FALSE, 20);
@@ -170,15 +171,15 @@ add_files_cb (GtkWidget *widget,
 	/* set data */
 
 	folder = eel_gconf_get_string (PREF_ADD_CURRENT_FOLDER, "");
-	if ((folder == NULL) || (strcmp (folder, "") == 0)) 
+	if ((folder == NULL) || (strcmp (folder, "") == 0))
 		folder = g_strdup (fr_window_get_add_default_dir (data->window));
 	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (file_sel), folder);
 	g_free (folder);
-	
+
 	/* signals */
 
 	g_signal_connect (G_OBJECT (file_sel),
-			  "destroy", 
+			  "destroy",
 			  G_CALLBACK (open_file_destroy_cb),
 			  data);
 
